Data handling
=============

.. automodule:: mumott.data_handling

.. autoclass:: mumott.data_handling.DataContainer
   :members:

.. autoclass:: mumott.data_handling.Geometry
   :members:

.. autoclass:: mumott.data_handling.geometry.GeometryTuple

.. autoclass:: mumott.data_handling.stack.Frame
   :members:

.. autoclass:: mumott.data_handling.stack.Stack
   :members:

